Learn R Programming

snpEnrichment (version 1.6.0)

getEnrichSNP: Get all eSNP/xSNP which are enriched

Description

getEnrichSNP get all eSNP/xSNP in a Enrichment object which are significant in the signal according to sigThresh defined in readEnrichment.

Usage

## S3 method for class 'Enrichment':
getEnrichSNP(object, type = "eSNP")

Arguments

object
[Enrichment]: an object of class Enrichment.
type
[character]: extract eSNP or xSNP data.

Value

  • Return a data.frame with eSNP/xSNP which are enriched in signal given to signalFile in function readEnrichment.

See Also

Overview : snpEnrichment-package Classes : Enrichment, Chromosome, EnrichSNP Methods : plot, reSample, getEnrichSNP, excludeSNP, compareEnrichment, enrichment, is.enrichment, chromosome, is.chromosome Functions : initFiles, writeLD, readEnrichment

Examples

Run this code
data(toyEnrichment)
eSNPenriched <- getEnrichSNP(object = toyEnrichment, type = "eSNP")
head(eSNPenriched)

Run the code above in your browser using DataLab