Usage
compareEnrichment(list1, list2, pattern = "Chrom", signalFile,
transcriptFile = FALSE, snpInfoDir,
distThresh = 1000, LD = FALSE,
ldThresh = 0.8, nSample = 100,
sigThresh = 0.05,
MAFpool = c(0.05, 0.10, 0.2, 0.3, 0.4, 0.5),
extendMethod = "ld",
mc.cores = detectCores())Arguments
list1, list2
[character or Enrichment]: character string naming a directory containing a list of SNPs for each chromosomes or an Enrichment object (fully filled).
pattern
[character]: character string containing a expression to be matched with all chromosomes files (e.g."Chrom" for files which start by "Chrom" followed by the chromosome number).
signalFile
[character]: the name of the signal file which the data are to be read from (2 columns: "SNP" and "PVALUE").
Each row of the table appears as one line of the file.
If it does not contain an _absolute_ path, the file name is _re
transcriptFile
[character or data.frame]: character string naming a file or a data.frame with four columns: Chromomosome, trancript's name, Starting and Ending positions.
data(trancript) can be use as parameters. Default is FALSE
snpInfoDir
[character]: character string naming a directory containing the reference data in a PLINK format (*.bed, *.bim and *.fam).
distThresh
[numeric]: maximal distance (kb) between SNP and gene. distThresh is used if transcriptFile is set.
LD
[logical]: LD=TRUE (default is FALSE) compute LD with PLINK.
Note that, this setting can increase the computation's time, depending on number of SNPs in the signal file.
ldThresh
[numeric]: threshold value for LD calculation (PLINK).
nSample
[numeric]: the number of resampling done by reSample for p-values computation (minimum is 100). sigThresh
[numeric]: statistical threshold for signal (e.g. sigThresh = 0.05 for a given GWAS signal) used to compute an Enrichment Ratio.
MAFpool
[vector(numeric)]: either a numeric vector giving the breaks points of intervals into which SNP's MAF (Minor Allele Frequency) is to be split.
extendMethod
[character]: character string naming the method to be used to extend the list of eSNPs.
Default is "ld", the list of eSNPs is extended with all SNPs in LD (r^2 threshold, defined in initFiles).
O mc.cores
[numeric]: The number of cores to use, i.e. at most how many child processes will be run simultaneously.
The option is initialized with detectCores.
Must be at least one, and parallelization requires at least two cores.