Learn R Programming

snpEnrichment (version 1.2-3)

excludeSNP: Exclude SNPs from Enrichment analysis

Description

Remove a specify set of SNPs and compute a new enrichment analysis.

Usage

excludeSNP(object, excludeFile, mc.cores = 1)

Arguments

object
[Enrichment]: an Enrichment object filled by reSample.
excludeFile
[vector(character)]: a list of SNPs to remove from a previous enrichment analysis. A path to a file which the first column are the SNPs.
mc.cores
[numeric]: The number of cores to use (default is mc.cores=1), i.e. at most how many child processes will be run simultaneously. Must be at least one, and parallelization requires at least two cores.

Value

  • Return the object given in argument where lists of SNPs are updated by removing SNPs in excludeFile.

See Also

Overview : snpEnrichment-package Classes : Enrichment, Chromosome, EnrichSNP Methods : plot, reSample, excludeSNP, compareEnrichment, enrichment, is.enrichment, chromosome, is.chromosome Functions : initFiles, writeLD, readEnrichment

Examples

Run this code
data(toyEnrichmentM1) # data(toyEnrichmentM2)
excludeFile <- c(
    "rs7897180", "rs4725479", "rs315404", "rs17390391", "rs1650670",
    "rs6783390", "rs1642009", "rs4756586", "rs11995037", "rs4977345",
    "rs13136448", "rs4233536", "rs11151079", "rs2299657", "rs4833930",
    "rs1384", "rs7168184", "rs6909895", "rs7972667", "rs2293229",
    "rs918216", "rs6040608", "rs2817715", "rs13233541", "rs4486743",
    "rs2127806", "rs10912854", "rs1869052", "rs9853549", "rs448658",
    "rs2451583", "rs17483288", "rs10962314", "rs9612059", "rs1384182",
    "rs8049208", "rs12215176", "rs2980996", "rs1736976", "rs8089268",
    "rs10832329", "rs12446540", "rs7676237", "rs869922", "rs16823426",
    "rs1374393", "rs13268781", "rs11134505", "rs7325241", "rs7520109"
)

toyM1_exclude <- excludeSNP(toyEnrichmentM1, excludeFile, mc.cores = 1)
toyM1_exclude

Run the code above in your browser using DataLab