[Enrichment or Chromosome]: an object to be updated. It is intended, an object returned by the readEnrichment function.
nSample
[numeric]: the number of resampling done by reSample for p-values computation (minimum is 100).
sigThresh
[numeric]: statistical threshold for signal (e.g. sigThresh = 0.05 for a given GWAS signal) used to compute an Enrichment Ratio.
MAFpool
[vector(numeric)]: either a numeric vector giving the breaks points of intervals into which SNP's MAF (Minor Allele Frequency) is to be split.
extendMethod
[character]: character string naming the method to be used to extend the list of eSNPs.
Default is "ld", the list of eSNPs is extended with all SNPs in LD (r^2 threshold, defined in writeLD).
Other
mc.cores
[numeric]: The number of cores to use (default is mc.cores=1), i.e. at most how many child processes will be run simultaneously.
Must be at least one, and parallelization requires at least two cores.
onlyGenome
[logical]: onlyGenome=FALSE (default) compute resampling step for all chromosomes.
Value
Return the object given in argument, updated by the resampling results.